PROCEDURE RedoTags
*-------------------------------------------------------------------------------
*-- Programmer..: David Love (DAVIDLOVE on the Borland Support Bulletin Board)
*-- Date........: 01/20/1992 (for dBASE IV version 1.1)
*-- Notes.......: This routine is a "generic" MDX cleanup routine. It is useful
*--               for handling "bloated" MDX files -- ones that have been around
*--               awhile (they tend to be larger than necessary). This routine
*--               will store the tag keys in an array, delete the tags, and then
*--               rebuild the MDX file from scratch, keeping all tag names and
*--               keys, and the MDX SHOULD be smaller.
*--             : Will act on the dbf's production mdx (ie. same name as dbf)
*-- Written for.: dBASE IV, 1.5
*-- Rev. History: 04/18/92 -- for use with beta version of dBASE IV, version 1.5
*--               (TAGCOUNT(), FOR(), DESCENDING(), UNIQUE() are 1.5 functions)
*-- Calls.......: None
*-- Called by...: Any
*-- Usage.......: do RedoTags with "<cDBF>"
*-- Example.....: do RedoTags with "Referral"
*-- Returns.....: None
*-- Parameters..: cDBF = Name of DATABASE file, no extension necessary.
*-------------------------------------------------------------------------------

    PARAMETER cDBF
	
    USE (cDBF)
    
    *-- First, figure out how many tags exist

    PRIVATE nMaxTags
    nMaxTags = TAGCOUNT( cDBF,1 )
    
    *-- only perform routine if an index tag exists
    if nMaxTags > 0
      PRIVATE nTags, mkey, mtag
	
      *-- store the keys and tags to an array
      DECLARE aTags[nMaxTags,5]
	  nTags = 1
      DO WHILE nTags <= nMaxTags
        STORE KEY( (cDBF),nTags) TO aTags[nTags,1]        && grab the key
        STORE TAG( (cDBF),nTags) TO aTags[nTags,2]        && grab the tagname
        STORE FOR( (cDBF),nTags) TO aTags[nTags,3]        && grab the for clause
        STORE DESCENDING( (cDBF),nTags) TO aTags[nTags,4] && .t. if descending
        STORE UNIQUE( (cDBF),nTags) TO aTags[nTags,5]     && .t. if unique
	    nTags = nTags + 1
      ENDDO
	
	  *-- now, delete the tags   
      DO WHILE "" # tag( (cDBF),1)
        DELETE TAG TAG( (cDBF),1)
      ENDDO
	  
	  *-- rebuild the MDX, tag by tag ...
	  nTags = 1
      DO WHILE nTags <= nMaxTags
        mkey = aTags[nTags,1]+iif(""#aTags[nTags,3]," FOR "+aTags[nTags,3],"") ;
          + iif(aTags[nTags,4]," DESCENDING","") ;
          + iif(aTags[nTags,5]," UNIQUE","")
	    mtag = aTags[nTags,2]
        INDEX ON &mkey. TAG &mtag.
	    nTags = nTags + 1
      ENDDO
	
	  *-- release the array ...
      RELEASE aTags
	
    ENDIF  && check for tags ...
    USE    && close database
    
RETURN
*-- EoP: RedoTags
